/**
 * @public
 */
export declare type Callback = (...args: any[]) => void;
/**
 * Basic event system
 *
 * @public
 */
export declare class Events<T> {
    private owner;
    private events;
    constructor(owner: T);
    /**
     * Bind an event to a `callback` function.
     *
     * @remarks
     * @param name - The name of the event
     * @param callback - The function to call when the even fires
     */
    on(name: string, callback: Callback): () => void;
    /**
     * Bind an event to only be triggered a single time.
     *
     * @param name - The name of the event
     * @param callback - The function to call when the even fires
     */
    once(name: string, callback: Callback): () => void;
    /**
     * Remove one callback
     *
     * @param callback - The function to unbind
     */
    off(callback?: Callback): void;
    /**
     * Trigger one or many events, firing all bound callbacks.
     *
     * @remarks
     * Callbacks are passed the same arguments as `trigger` is, apart from the event name
     * (unless you're listening on `"all"`, which will cause your callback to
     * receive the true name of the event as the first argument).
     *
     * @param name - The name of the event to trigger
     */
    trigger(name: string, ...args: any[]): void;
}
//# sourceMappingURL=events.d.ts.map