import { InstanceState } from './models';
/**
 * Describes a SpriteSpin input state
 *
 * @public
 */
export interface InputState {
    oldX: number;
    oldY: number;
    currentX: number;
    currentY: number;
    startX: number;
    startY: number;
    clickframe: number;
    clicklane: number;
    dX: number;
    dY: number;
    ddX: number;
    ddY: number;
    ndX: number;
    ndY: number;
    nddX: number;
    nddY: number;
}
/**
 * Gets the current input state which is stored in the given instance state
 *
 * @public
 * @param state - The SpriteSpin instance state
 */
export declare function getInputState(state: InstanceState): InputState;
/**
 * Updates the input state using a mouse or touch event.
 *
 * @public
 * @param e - The input event
 * @param state - The SpriteSpin instance state
 *
 * @remarks
 * Detects current mouse or pointer location and updates the input state. Does not trigger any event.
 */
export declare function updateInput(e: {
    clientX: number;
    clientY: number;
}, state: InstanceState): void;
/**
 * Resets the input state.
 *
 * @public
 * @param state - The SpriteSpin instance state
 *
 * @remarks
 * Simply clears the input state. Does not trigger any event.
 */
export declare function resetInput(state: InstanceState): void;
//# sourceMappingURL=input.d.ts.map