import { Loop } from '../utils';
import { InstanceState } from './models';
/**
 * Gets the playback state
 *
 * @public
 * @param instance - The SpriteSpin instance state
 */
export declare function getPlaybackState(instance: InstanceState): PlaybackState;
/**
 * The playback state
 *
 * @public
 */
export interface PlaybackState {
    /**
     * The time between frames
     */
    frameTime: number;
    /**
     * The time when the last update occured
     */
    lastTime: number;
    /**
     * The frame number at last frame
     */
    lastFrame: number;
    /**
     * The lane number at last frame
     */
    lastLane: number;
    /**
     * The animation looper
     */
    looper: Loop;
}
/**
 * Updates the frame or lane number of the SpriteSpin data.
 *
 * @public
 * @param data - The SpriteSpin instance state
 * @param frame - The frame number to set
 * @param lane - The lane number to set
 */
export declare function updateFrame(data: InstanceState, frame?: number, lane?: number): void;
/**
 * Starts animation playback if needed.
 *
 * @remarks
 * Starts animation playback if `animate` property is `true` and the animation is not yet running.
 *
 * @public
 * @param data - The SpriteSpin instance state
 */
export declare function usePlayback(data: InstanceState): void;
/**
 * Stops the running animation.
 *
 * @public
 * @param data - The SpriteSpin instance state
 */
export declare function stopAnimation(data: InstanceState): void;
/**
 * Starts the animation playback
 *
 * @remarks
 * Starts the animation playback and also sets the `animate` property to `true`
 *
 * @public
 * @param state - The SpriteSpin instance state
 */
export declare function startAnimation(state: InstanceState): void;
//# sourceMappingURL=playback.d.ts.map