import type { InstanceState, PluginType, PluginInstance } from './models';
/**
 * Registers a plugin to the spritespin plugin pool
 *
 * @public
 * @param name - The name of the plugin
 * @param plugin - The plugin implementation
 */
export declare function registerPlugin(name: string, plugin: PluginType): void;
/**
 * Gets a plugin state object by name.
 *
 * @remarks
 * Plugins should use this method to get or create a state object where they can
 * store any instance variables.
 *
 * @public
 * @param state - The SpriteSpin instance state
 * @param pluginName - The name of the plugin
 */
export declare function getPluginState<T extends object = any>(state: InstanceState, pluginName: string, orCreate?: () => T): T;
/**
 * Gets the user options given for the plugin
 *
 * @public
 * @param state - The SpriteSpin instance state
 * @param name - The plugin name
 * @returns
 */
export declare function getPluginOptions(state: InstanceState, name: string): any;
/**
 * Gets an instance of an active plugin by name
 *
 * @param state - The SpriteSpin instance state
 * @param name - The plugin name
 * @returns
 */
export declare function getPluginInstance(state: InstanceState, name: string): PluginInstance | null;
/**
 * Replaces module names on given SpriteSpin data and replaces them with actual implementations.
 * @public
 */
export declare function usePlugins(state: InstanceState, actions: {
    onCreated: (p: PluginInstance) => void;
    onRemoved: (p: PluginInstance) => void;
}): void;
//# sourceMappingURL=plugins.d.ts.map