import { Instance, InstanceExtension } from '../core';
export declare type CommonApi = Instance & CommonApiFunctions;
export interface CommonApiFunctions extends InstanceExtension {
    /**
     * Gets a value indicating whether the animation is currently running.
     */
    isPlaying: () => boolean;
    /**
     * Gets a value indicating whether the animation looping is enabled.
     */
    isLooping: () => boolean;
    /**
     * Starts/Stops the animation playback
     */
    toggleAnimation: () => void;
    /**
     * Stops animation playback
     */
    stopAnimation: () => void;
    /**
     * Starts animation playback
     */
    startAnimation: () => void;
    /**
     * Sets a value indicating whether the animation should be looped or not.
     * This might start the animation (if the 'animate' data attribute is set to true)
     */
    loop: (value: boolean) => void;
    /**
     * Gets the current frame number
     */
    currentFrame: () => number;
    /**
     * Updates SpriteSpin to the specified frame.
     */
    updateFrame: (frame: number, lane?: number) => void;
    /**
     * Skips the given number of frames
     */
    skipFrames: (step: number) => void;
    /**
     * Updates SpriteSpin so that the next frame is shown
     */
    nextFrame: () => void;
    /**
     * Updates SpriteSpin so that the previous frame is shown
     */
    prevFrame: () => void;
    /**
     * Starts the animations that will play until the given frame number is reached
     * options:
     *   force [boolean] starts the animation, even if current frame is the target frame
     *   nearest [boolean] animates to the direction with minimum distance to the target frame
     */
    playTo: (frame: number, options?: {
        force?: boolean;
        nearest?: boolean;
    }) => void;
}
//# sourceMappingURL=common.d.ts.map