/**
 * Options for {@link sourceArray} function
 */
export interface SourceArrayOptions {
    /**
     * Minimum number of digits
     */
    digits?: number;
    /**
     * Start and end frame numbers
     */
    frame?: number[];
    /**
     * Start and end lane numbers
     */
    lane?: number[];
    /**
     * Variable to be replaced by a frame number e.g. '{frame}'
     */
    framePlacer?: string;
    /**
     * Variable to be replaced by a lane number e.g. '{lane}'
     */
    lanePlacer?: string;
}
/**
 * Generates an array of source strings
 *
 * @remarks
 * Takes a template string and generates an array of strings by interpolating {lane} and {frame} placeholders.
 *
 * ```
 * sourceArray('http://example.com/image_{frame}.jpg, { frame: [1, 3], digits: 2 })
 * // gives:
 * // [ 'http://example.com/image_01.jpg', 'http://example.com/image_02.jpg', 'http://example.com/image_03.jpg' ]
 *
 * sourceArray('http://example.com/image_FRAME.jpg, { frame: [1, 3], digits: 2, framePlacer: 'FRAME' })
 * // gives:
 * // [ 'http://example.com/image_01.jpg', 'http://example.com/image_02.jpg', 'http://example.com/image_03.jpg' ]
 * ```
 *
 * @param template - The template string
 * @param opts - Interpolation options
 *
 * @public
 */
export declare function sourceArray(template: string, opts: SourceArrayOptions): string[];
//# sourceMappingURL=sourceArray.d.ts.map